@@ -37,6 +37,7 @@ for which a new license (GPL+exception) is in place.
 #include <QStringList>
 #include <QTimer>
 #include <QFile>
+#include <QUuid>
 
 #include "appmodes.h"
 #include "gtgettext.h" //CB For the ImportSetup struct and itemadduserframe
@@ -99,6 +100,7 @@ public:
 	~ScribusDoc();
 
 	void init();
+	QString uuidString() {return m_uuid.toString(QUuid::WithoutBraces);}
 	bool inAnEditMode() const;
 	bool inASpecialEditMode() const;
 	QList<PageItem*> getAllItems(const QList<PageItem*> &items) const;
@@ -1306,6 +1308,7 @@ protected:
 	bool m_symbolEditMode {false};
 	bool m_inlineEditMode {false};
 	int  m_storedLayerID {0};
+	int  m_storedFirstLayerID {0};
 	bool m_storedLayerLock {false};
 	bool m_storedLayerVis {false};
 	QMap<QString, double> m_constants;
@@ -1317,6 +1320,7 @@ protected:
 	QString m_currentEditedSymbol;
 	int m_currentEditedIFrame {0};
 	QString m_documentFileName;
+	QUuid m_uuid;
 
 public: // Public attributes
 	bool is12doc {false}; //public for now, it will be removed later
